@@ -8,9 +8,9 @@ localmoran.exact.alt <- function(model, select, nb, glist = NULL, style = "W",
 # class to inherits Jari Oksanen 080603
     if (!inherits(nb, "nb"))
         stop(paste(deparse(substitute(nb)), "not an nb object"))
-        if (is.null(zero.policy))
-            zero.policy <- get("zeroPolicy", envir = .spdepOptions)
-        stopifnot(is.logical(zero.policy))
+    if (is.null(zero.policy))
+        zero.policy <- get.ZeroPolicyOption()
+    stopifnot(is.logical(zero.policy))
 #    if (class(model) != "lm") 
 #        stop(paste(deparse(substitute(model)), "not an lm object"))
     dmc <- deparse(model$call)
@@ -64,21 +64,10 @@ localmoran.exact.alt <- function(model, select, nb, glist = NULL, style = "W",
 	a <- sum(sapply(B$weights, function(x) sqrt(sum(x^2))))
     } else if (style == "C") a <- sum(unlist(B$weights))
 
-    cores <- get.coresOption()
-    if (is.null(cores)) {
-        parallel <- "no"
-    } else {
-        parallel <- ifelse (get.mcOption(), "multicore", "snow")
-    }
-    ncpus <- ifelse(is.null(cores), 1L, cores)
-    cl <- NULL
-    if (parallel == "snow") {
-        cl <- get.ClusterOption()
-        if (is.null(cl)) {
-            parallel <- "no"
-            warning("no cluster in ClusterOption, parallel set to no")
-        }
-    }
+    p_setup <- parallel_setup(NULL)
+    parallel <- p_setup$parallel
+    ncpus <- p_setup$ncpus
+    cl <- p_setup$cl
 
     exactLocalMoranAlt_int <- function(i, B, select, style, n, D, a, 
         zero.policy, u, utu, M1, M2, useTP, truncErr, zeroTreat, alternative) {
