@@ -4,7 +4,7 @@
 
 SEXP nbdists(SEXP nb, SEXP x, SEXP np, SEXP dim, SEXP lonlat)
 {
-	int i, j, j1, k, /* m,*/ n, d, pc=0, ll;
+	int i, j, j1, k, /* m,*/ n, d, pc=0, ll, first_value;
 	SEXP ans;
         SEXP class;
 	double lon1[1], lon2[1], lat1[1], lat2[1], gc[1];
@@ -16,21 +16,27 @@ SEXP nbdists(SEXP nb, SEXP x, SEXP np, SEXP dim, SEXP lonlat)
 
 	SET_VECTOR_ELT(ans, 0, NEW_LIST(n));
 	d = INTEGER_POINTER(dim)[0];
-	if (d > 2) error("Only 2D coordinates allowed");
+	if (d > 2) Rf_error("Only 2D coordinates allowed");
 	PROTECT(class = NEW_CHARACTER(1)); pc++;
 	SET_STRING_ELT(class, 0, COPY_TO_USER_STRING("nbdist"));
-	setAttrib(VECTOR_ELT(ans, 0), R_ClassSymbol, class);
+	Rf_setAttrib(VECTOR_ELT(ans, 0), R_ClassSymbol, class);
 
 	for (i=0; i < n; i++) {
                 R_CheckUserInterrupt();
-		k = length(VECTOR_ELT(nb, i));
+		k = Rf_length(VECTOR_ELT(nb, i));
 /*		if (k == 1 && INTEGER_POINTER(VECTOR_ELT(nb, i))[0] == 0) {
 			SET_VECTOR_ELT(VECTOR_ELT(ans, 0), i,
 				NEW_NUMERIC(1));
 			NUMERIC_POINTER(VECTOR_ELT(VECTOR_ELT(ans, 0), i))[0]
 				= NA_REAL;
 		} else { */
-		if (INTEGER_POINTER(VECTOR_ELT(nb, i))[0] > 0) {
+
+                if (k > 0) 
+                    first_value = INTEGER_POINTER(VECTOR_ELT(nb, i))[0];
+                else
+                    Rf_error("zero length neighbour vector");
+
+		if (first_value > 0) {
 			SET_VECTOR_ELT(VECTOR_ELT(ans, 0), i,
 				NEW_NUMERIC(k));
 			for (j=0; j < k; j++) {
